# coding: utf-8

"""
    servicehub-scim-api

    API endpoints for user management, utilizing the SCIM protocol.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class SCIMApi(object):
    base_path = "user-management/scim"

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def create_user(self, body, **kwargs):  # noqa: E501
        """Create A User  # noqa: E501

        Create a new user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimUser body: The user object to be created. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_user_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_user_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create A User  # noqa: E501

        Create a new user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimUser body: The user object to be created. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user_by_id(self, user_id, **kwargs):  # noqa: E501
        """Delete User By ID  # noqa: E501

        Deletes a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_by_id(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to be deleted. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_by_id_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_by_id_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def delete_user_by_id_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Delete User By ID  # noqa: E501

        Deletes a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_by_id_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to be deleted. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `delete_user_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_groups(self, **kwargs):  # noqa: E501
        """Get All Groups  # noqa: E501

        Retrieve a list of all groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ScimGroupList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get All Groups  # noqa: E501

        Retrieve a list of all groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ScimGroupList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_groups" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimGroupList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_roles(self, **kwargs):  # noqa: E501
        """Get All Roles  # noqa: E501

        Retrieve a list of all roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Optional filter parameter for refining the role list.
        :param int start_index: Optional startIndex parameter for refining the role list.
        :param int count: Optional count parameter for refining the role list.
        :param str sort_by: Optional sortBy parameter for refining the role list.
        :param str sort_order: Optional sortOrder parameter for refining the role list.
        :return: ScimRoleList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_roles_with_http_info(self, **kwargs):  # noqa: E501
        """Get All Roles  # noqa: E501

        Retrieve a list of all roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Optional filter parameter for refining the role list.
        :param int start_index: Optional startIndex parameter for refining the role list.
        :param int count: Optional count parameter for refining the role list.
        :param str sort_by: Optional sortBy parameter for refining the role list.
        :param str sort_order: Optional sortOrder parameter for refining the role list.
        :return: ScimRoleList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'start_index', 'count', 'sort_by', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('startIndex', params['start_index']))  # noqa: E501
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimRoleList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_users(self, **kwargs):  # noqa: E501
        """Get All Users  # noqa: E501

        Retrieve a list of all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Optional filter parameter for refining the user list.
        :return: ScimUserList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_users_with_http_info(self, **kwargs):  # noqa: E501
        """Get All Users  # noqa: E501

        Retrieve a list of all users.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Optional filter parameter for refining the user list.
        :return: ScimUserList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_users" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimUserList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_by_id(self, user_id, **kwargs):  # noqa: E501
        """Get User By ID  # noqa: E501

        Retrieve a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_by_id(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to be retrieved. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_by_id_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_by_id_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def get_user_by_id_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get User By ID  # noqa: E501

        Retrieve a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_by_id_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: ID of the user to be retrieved. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_user_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_user_by_id(self, body, user_id, **kwargs):  # noqa: E501
        """Patch User By ID  # noqa: E501

        Patch specified fields of a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_user_by_id(body, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimPatchRequest body: The patch request specifying fields to be updated. (required)
        :param str user_id: ID of the user to be patched. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_user_by_id_with_http_info(body, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_user_by_id_with_http_info(body, user_id, **kwargs)  # noqa: E501
            return data

    def patch_user_by_id_with_http_info(self, body, user_id, **kwargs):  # noqa: E501
        """Patch User By ID  # noqa: E501

        Patch specified fields of a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_user_by_id_with_http_info(body, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimPatchRequest body: The patch request specifying fields to be updated. (required)
        :param str user_id: ID of the user to be patched. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_user_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_user_by_id`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `patch_user_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users/{userId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_by_id(self, body, user_id, **kwargs):  # noqa: E501
        """Update User By ID  # noqa: E501

        Update a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_by_id(body, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimUser body: The updated user object. (required)
        :param str user_id: ID of the user to be updated. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_by_id_with_http_info(body, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_by_id_with_http_info(body, user_id, **kwargs)  # noqa: E501
            return data

    def update_user_by_id_with_http_info(self, body, user_id, **kwargs):  # noqa: E501
        """Update User By ID  # noqa: E501

        Update a user by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_by_id_with_http_info(body, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ScimUser body: The updated user object. (required)
        :param str user_id: ID of the user to be updated. (required)
        :return: ScimUser
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_user_by_id`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `update_user_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/Users/{userId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScimUser',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetWorkflowStatusResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status_code': 'str',
        'status_type': 'str',
        'associated_workflows': 'list[GetWorkflowStatusResponseAssociatedWorkflows]',
        'created_by_recruiter_info': 'GetWorkflowStatusResponseCreatedByRecruiterInfo',
        'created_date': 'str',
        'updated_date': 'str'
    }

    attribute_map = {
        'name': 'name',
        'status_code': 'statusCode',
        'status_type': 'statusType',
        'associated_workflows': 'associatedWorkflows',
        'created_by_recruiter_info': 'createdByRecruiterInfo',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate'
    }

    def __init__(self, name=None, status_code=None, status_type=None, associated_workflows=None, created_by_recruiter_info=None, created_date=None, updated_date=None):  # noqa: E501
        """GetWorkflowStatusResponseData - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._status_code = None
        self._status_type = None
        self._associated_workflows = None
        self._created_by_recruiter_info = None
        self._created_date = None
        self._updated_date = None
        self.discriminator = None
        self.name = name
        self.status_code = status_code
        self.status_type = status_type
        self.associated_workflows = associated_workflows
        self.created_by_recruiter_info = created_by_recruiter_info
        self.created_date = created_date
        self.updated_date = updated_date

    @property
    def name(self):
        """Gets the name of this GetWorkflowStatusResponseData.  # noqa: E501

        Name of the workflow status.  # noqa: E501

        :return: The name of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetWorkflowStatusResponseData.

        Name of the workflow status.  # noqa: E501

        :param name: The name of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this GetWorkflowStatusResponseData.  # noqa: E501

        Status code associated with the workflow status.  # noqa: E501

        :return: The status_code of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this GetWorkflowStatusResponseData.

        Status code associated with the workflow status.  # noqa: E501

        :param status_code: The status_code of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    @property
    def status_type(self):
        """Gets the status_type of this GetWorkflowStatusResponseData.  # noqa: E501

        Type of the workflow status.  # noqa: E501

        :return: The status_type of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status_type

    @status_type.setter
    def status_type(self, status_type):
        """Sets the status_type of this GetWorkflowStatusResponseData.

        Type of the workflow status.  # noqa: E501

        :param status_type: The status_type of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if status_type is None:
            raise ValueError("Invalid value for `status_type`, must not be `None`")  # noqa: E501

        self._status_type = status_type

    @property
    def associated_workflows(self):
        """Gets the associated_workflows of this GetWorkflowStatusResponseData.  # noqa: E501

        List of associated workflows.  # noqa: E501

        :return: The associated_workflows of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: list[GetWorkflowStatusResponseAssociatedWorkflows]
        """
        return self._associated_workflows

    @associated_workflows.setter
    def associated_workflows(self, associated_workflows):
        """Sets the associated_workflows of this GetWorkflowStatusResponseData.

        List of associated workflows.  # noqa: E501

        :param associated_workflows: The associated_workflows of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: list[GetWorkflowStatusResponseAssociatedWorkflows]
        """
        if associated_workflows is None:
            raise ValueError("Invalid value for `associated_workflows`, must not be `None`")  # noqa: E501

        self._associated_workflows = associated_workflows

    @property
    def created_by_recruiter_info(self):
        """Gets the created_by_recruiter_info of this GetWorkflowStatusResponseData.  # noqa: E501


        :return: The created_by_recruiter_info of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: GetWorkflowStatusResponseCreatedByRecruiterInfo
        """
        return self._created_by_recruiter_info

    @created_by_recruiter_info.setter
    def created_by_recruiter_info(self, created_by_recruiter_info):
        """Sets the created_by_recruiter_info of this GetWorkflowStatusResponseData.


        :param created_by_recruiter_info: The created_by_recruiter_info of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: GetWorkflowStatusResponseCreatedByRecruiterInfo
        """
        if created_by_recruiter_info is None:
            raise ValueError("Invalid value for `created_by_recruiter_info`, must not be `None`")  # noqa: E501

        self._created_by_recruiter_info = created_by_recruiter_info

    @property
    def created_date(self):
        """Gets the created_date of this GetWorkflowStatusResponseData.  # noqa: E501

        Timestamp of when the status was created.  # noqa: E501

        :return: The created_date of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetWorkflowStatusResponseData.

        Timestamp of when the status was created.  # noqa: E501

        :param created_date: The created_date of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this GetWorkflowStatusResponseData.  # noqa: E501

        Timestamp of when the status was last updated.  # noqa: E501

        :return: The updated_date of this GetWorkflowStatusResponseData.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetWorkflowStatusResponseData.

        Timestamp of when the status was last updated.  # noqa: E501

        :param updated_date: The updated_date of this GetWorkflowStatusResponseData.  # noqa: E501
        :type: str
        """
        if updated_date is None:
            raise ValueError("Invalid value for `updated_date`, must not be `None`")  # noqa: E501

        self._updated_date = updated_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetWorkflowStatusResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetWorkflowStatusResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateProjectRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'project_description': 'str',
        'is_confidential': 'bool',
        'category_list': 'list[UpdateProjectRequestCategoryList]',
        'end_date': 'str',
        'updated_recruiter_info': 'UpdateProjectRequestUpdatedRecruiterInfo',
        'candidate_infos': 'list[UpdateProjectRequestCandidateInfos]'
    }

    attribute_map = {
        'project_name': 'projectName',
        'project_description': 'projectDescription',
        'is_confidential': 'isConfidential',
        'category_list': 'categoryList',
        'end_date': 'endDate',
        'updated_recruiter_info': 'updatedRecruiterInfo',
        'candidate_infos': 'candidateInfos'
    }

    def __init__(self, project_name=None, project_description=None, is_confidential=None, category_list=None, end_date=None, updated_recruiter_info=None, candidate_infos=None):  # noqa: E501
        """UpdateProjectRequest - a model defined in Swagger"""  # noqa: E501
        self._project_name = None
        self._project_description = None
        self._is_confidential = None
        self._category_list = None
        self._end_date = None
        self._updated_recruiter_info = None
        self._candidate_infos = None
        self.discriminator = None
        if project_name is not None:
            self.project_name = project_name
        if project_description is not None:
            self.project_description = project_description
        if is_confidential is not None:
            self.is_confidential = is_confidential
        if category_list is not None:
            self.category_list = category_list
        if end_date is not None:
            self.end_date = end_date
        if updated_recruiter_info is not None:
            self.updated_recruiter_info = updated_recruiter_info
        if candidate_infos is not None:
            self.candidate_infos = candidate_infos

    @property
    def project_name(self):
        """Gets the project_name of this UpdateProjectRequest.  # noqa: E501

        Updated name of the project.  # noqa: E501

        :return: The project_name of this UpdateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this UpdateProjectRequest.

        Updated name of the project.  # noqa: E501

        :param project_name: The project_name of this UpdateProjectRequest.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def project_description(self):
        """Gets the project_description of this UpdateProjectRequest.  # noqa: E501

        Updated description of the project.  # noqa: E501

        :return: The project_description of this UpdateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._project_description

    @project_description.setter
    def project_description(self, project_description):
        """Sets the project_description of this UpdateProjectRequest.

        Updated description of the project.  # noqa: E501

        :param project_description: The project_description of this UpdateProjectRequest.  # noqa: E501
        :type: str
        """

        self._project_description = project_description

    @property
    def is_confidential(self):
        """Gets the is_confidential of this UpdateProjectRequest.  # noqa: E501

        Flag indicating whether the project is confidential.  # noqa: E501

        :return: The is_confidential of this UpdateProjectRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_confidential

    @is_confidential.setter
    def is_confidential(self, is_confidential):
        """Sets the is_confidential of this UpdateProjectRequest.

        Flag indicating whether the project is confidential.  # noqa: E501

        :param is_confidential: The is_confidential of this UpdateProjectRequest.  # noqa: E501
        :type: bool
        """

        self._is_confidential = is_confidential

    @property
    def category_list(self):
        """Gets the category_list of this UpdateProjectRequest.  # noqa: E501

        Updated list of project categories.  # noqa: E501

        :return: The category_list of this UpdateProjectRequest.  # noqa: E501
        :rtype: list[UpdateProjectRequestCategoryList]
        """
        return self._category_list

    @category_list.setter
    def category_list(self, category_list):
        """Sets the category_list of this UpdateProjectRequest.

        Updated list of project categories.  # noqa: E501

        :param category_list: The category_list of this UpdateProjectRequest.  # noqa: E501
        :type: list[UpdateProjectRequestCategoryList]
        """

        self._category_list = category_list

    @property
    def end_date(self):
        """Gets the end_date of this UpdateProjectRequest.  # noqa: E501

        Updated end date of the project.  # noqa: E501

        :return: The end_date of this UpdateProjectRequest.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this UpdateProjectRequest.

        Updated end date of the project.  # noqa: E501

        :param end_date: The end_date of this UpdateProjectRequest.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def updated_recruiter_info(self):
        """Gets the updated_recruiter_info of this UpdateProjectRequest.  # noqa: E501


        :return: The updated_recruiter_info of this UpdateProjectRequest.  # noqa: E501
        :rtype: UpdateProjectRequestUpdatedRecruiterInfo
        """
        return self._updated_recruiter_info

    @updated_recruiter_info.setter
    def updated_recruiter_info(self, updated_recruiter_info):
        """Sets the updated_recruiter_info of this UpdateProjectRequest.


        :param updated_recruiter_info: The updated_recruiter_info of this UpdateProjectRequest.  # noqa: E501
        :type: UpdateProjectRequestUpdatedRecruiterInfo
        """

        self._updated_recruiter_info = updated_recruiter_info

    @property
    def candidate_infos(self):
        """Gets the candidate_infos of this UpdateProjectRequest.  # noqa: E501

        List of candidate information to be added or updated in the project.  # noqa: E501

        :return: The candidate_infos of this UpdateProjectRequest.  # noqa: E501
        :rtype: list[UpdateProjectRequestCandidateInfos]
        """
        return self._candidate_infos

    @candidate_infos.setter
    def candidate_infos(self, candidate_infos):
        """Sets the candidate_infos of this UpdateProjectRequest.

        List of candidate information to be added or updated in the project.  # noqa: E501

        :param candidate_infos: The candidate_infos of this UpdateProjectRequest.  # noqa: E501
        :type: list[UpdateProjectRequestCandidateInfos]
        """

        self._candidate_infos = candidate_infos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateProjectRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateProjectRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class UserManagementApi(object):
    base_path = "/user-management"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def search_user(self, body, **kwargs):  # noqa: E501
        """Search Users  # noqa: E501

        Search for users based on specified criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_user(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchRequest body: The request object containing search criteria. (required)
        :return: SearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_user_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.search_user_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def search_user_with_http_info(self, body, **kwargs):  # noqa: E501
        """Search Users  # noqa: E501

        Search for users based on specified criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_user_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SearchRequest body: The request object containing search criteria. (required)
        :return: SearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_user" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `search_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/users/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    employees-api-careerpath

    The Employee upskill APIs are related to the career pathing that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCareerPath(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'list[PathItem]',
        'current_job_profile': 'CurrentJobProfile',
        'path_id': 'str'
    }

    attribute_map = {
        'path': 'path',
        'current_job_profile': 'currentJobProfile',
        'path_id': 'pathId'
    }

    def __init__(self, path=None, current_job_profile=None, path_id='8168055'):  # noqa: E501
        """UpdateCareerPath - a model defined in Swagger"""  # noqa: E501
        self._path = None
        self._current_job_profile = None
        self._path_id = None
        self.discriminator = None
        if path is not None:
            self.path = path
        if current_job_profile is not None:
            self.current_job_profile = current_job_profile
        if path_id is not None:
            self.path_id = path_id

    @property
    def path(self):
        """Gets the path of this UpdateCareerPath.  # noqa: E501


        :return: The path of this UpdateCareerPath.  # noqa: E501
        :rtype: list[PathItem]
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this UpdateCareerPath.


        :param path: The path of this UpdateCareerPath.  # noqa: E501
        :type: list[PathItem]
        """

        self._path = path

    @property
    def current_job_profile(self):
        """Gets the current_job_profile of this UpdateCareerPath.  # noqa: E501


        :return: The current_job_profile of this UpdateCareerPath.  # noqa: E501
        :rtype: CurrentJobProfile
        """
        return self._current_job_profile

    @current_job_profile.setter
    def current_job_profile(self, current_job_profile):
        """Sets the current_job_profile of this UpdateCareerPath.


        :param current_job_profile: The current_job_profile of this UpdateCareerPath.  # noqa: E501
        :type: CurrentJobProfile
        """

        self._current_job_profile = current_job_profile

    @property
    def path_id(self):
        """Gets the path_id of this UpdateCareerPath.  # noqa: E501

        Path Id - unique field to identify the careerPath of the employee.  # noqa: E501

        :return: The path_id of this UpdateCareerPath.  # noqa: E501
        :rtype: str
        """
        return self._path_id

    @path_id.setter
    def path_id(self, path_id):
        """Sets the path_id of this UpdateCareerPath.

        Path Id - unique field to identify the careerPath of the employee.  # noqa: E501

        :param path_id: The path_id of this UpdateCareerPath.  # noqa: E501
        :type: str
        """

        self._path_id = path_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCareerPath, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCareerPath):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataAttachments(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiter_user_id': 'str',
        'created_date': 'str',
        'document_type': 'str',
        'attachment_type': 'str',
        'md5sum': 'str',
        'relative_path': 'str',
        'recruiter_name': 'str',
        'resume_file_name': 'str',
        'document_status': 'str',
        'bucket_id': 'str',
        'is_created_from_candidates': 'bool',
        'field_id': 'str'
    }

    attribute_map = {
        'recruiter_user_id': 'recruiterUserId',
        'created_date': 'createdDate',
        'document_type': 'documentType',
        'attachment_type': 'attachmentType',
        'md5sum': 'md5sum',
        'relative_path': 'relativePath',
        'recruiter_name': 'recruiterName',
        'resume_file_name': 'resumeFileName',
        'document_status': 'documentStatus',
        'bucket_id': 'bucketId',
        'is_created_from_candidates': 'isCreatedFromCandidates',
        'field_id': 'fieldID'
    }

    def __init__(self, recruiter_user_id=None, created_date=None, document_type=None, attachment_type=None, md5sum=None, relative_path=None, recruiter_name=None, resume_file_name=None, document_status=None, bucket_id=None, is_created_from_candidates=None, field_id=None):  # noqa: E501
        """GetCandidatesResponseDataAttachments - a model defined in Swagger"""  # noqa: E501
        self._recruiter_user_id = None
        self._created_date = None
        self._document_type = None
        self._attachment_type = None
        self._md5sum = None
        self._relative_path = None
        self._recruiter_name = None
        self._resume_file_name = None
        self._document_status = None
        self._bucket_id = None
        self._is_created_from_candidates = None
        self._field_id = None
        self.discriminator = None
        if recruiter_user_id is not None:
            self.recruiter_user_id = recruiter_user_id
        if created_date is not None:
            self.created_date = created_date
        if document_type is not None:
            self.document_type = document_type
        if attachment_type is not None:
            self.attachment_type = attachment_type
        if md5sum is not None:
            self.md5sum = md5sum
        if relative_path is not None:
            self.relative_path = relative_path
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if resume_file_name is not None:
            self.resume_file_name = resume_file_name
        if document_status is not None:
            self.document_status = document_status
        if bucket_id is not None:
            self.bucket_id = bucket_id
        if is_created_from_candidates is not None:
            self.is_created_from_candidates = is_created_from_candidates
        if field_id is not None:
            self.field_id = field_id

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetCandidatesResponseDataAttachments.  # noqa: E501

        User ID of the recruiter who attached this file.  # noqa: E501

        :return: The recruiter_user_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetCandidatesResponseDataAttachments.

        User ID of the recruiter who attached this file.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._recruiter_user_id = recruiter_user_id

    @property
    def created_date(self):
        """Gets the created_date of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Creation date of the attachment.  # noqa: E501

        :return: The created_date of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetCandidatesResponseDataAttachments.

        Creation date of the attachment.  # noqa: E501

        :param created_date: The created_date of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def document_type(self):
        """Gets the document_type of this GetCandidatesResponseDataAttachments.  # noqa: E501

        File type of the attachment.  # noqa: E501

        :return: The document_type of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this GetCandidatesResponseDataAttachments.

        File type of the attachment.  # noqa: E501

        :param document_type: The document_type of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def attachment_type(self):
        """Gets the attachment_type of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Type of the attachment.  # noqa: E501

        :return: The attachment_type of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this GetCandidatesResponseDataAttachments.

        Type of the attachment.  # noqa: E501

        :param attachment_type: The attachment_type of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    @property
    def md5sum(self):
        """Gets the md5sum of this GetCandidatesResponseDataAttachments.  # noqa: E501

        MD5 checksum of the attachment.  # noqa: E501

        :return: The md5sum of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._md5sum

    @md5sum.setter
    def md5sum(self, md5sum):
        """Sets the md5sum of this GetCandidatesResponseDataAttachments.

        MD5 checksum of the attachment.  # noqa: E501

        :param md5sum: The md5sum of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._md5sum = md5sum

    @property
    def relative_path(self):
        """Gets the relative_path of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Relative path of the attachment.  # noqa: E501

        :return: The relative_path of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._relative_path

    @relative_path.setter
    def relative_path(self, relative_path):
        """Sets the relative_path of this GetCandidatesResponseDataAttachments.

        Relative path of the attachment.  # noqa: E501

        :param relative_path: The relative_path of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._relative_path = relative_path

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Name of the recruiter who attached this file.  # noqa: E501

        :return: The recruiter_name of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetCandidatesResponseDataAttachments.

        Name of the recruiter who attached this file.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def resume_file_name(self):
        """Gets the resume_file_name of this GetCandidatesResponseDataAttachments.  # noqa: E501

        File name of the resume.  # noqa: E501

        :return: The resume_file_name of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._resume_file_name

    @resume_file_name.setter
    def resume_file_name(self, resume_file_name):
        """Sets the resume_file_name of this GetCandidatesResponseDataAttachments.

        File name of the resume.  # noqa: E501

        :param resume_file_name: The resume_file_name of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._resume_file_name = resume_file_name

    @property
    def document_status(self):
        """Gets the document_status of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Status of the document.  # noqa: E501

        :return: The document_status of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._document_status

    @document_status.setter
    def document_status(self, document_status):
        """Sets the document_status of this GetCandidatesResponseDataAttachments.

        Status of the document.  # noqa: E501

        :param document_status: The document_status of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._document_status = document_status

    @property
    def bucket_id(self):
        """Gets the bucket_id of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Identifier of the storage bucket.  # noqa: E501

        :return: The bucket_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._bucket_id

    @bucket_id.setter
    def bucket_id(self, bucket_id):
        """Sets the bucket_id of this GetCandidatesResponseDataAttachments.

        Identifier of the storage bucket.  # noqa: E501

        :param bucket_id: The bucket_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._bucket_id = bucket_id

    @property
    def is_created_from_candidates(self):
        """Gets the is_created_from_candidates of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Indicates if the attachment is created from candidate data.  # noqa: E501

        :return: The is_created_from_candidates of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: bool
        """
        return self._is_created_from_candidates

    @is_created_from_candidates.setter
    def is_created_from_candidates(self, is_created_from_candidates):
        """Sets the is_created_from_candidates of this GetCandidatesResponseDataAttachments.

        Indicates if the attachment is created from candidate data.  # noqa: E501

        :param is_created_from_candidates: The is_created_from_candidates of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: bool
        """

        self._is_created_from_candidates = is_created_from_candidates

    @property
    def field_id(self):
        """Gets the field_id of this GetCandidatesResponseDataAttachments.  # noqa: E501

        Field identifier for the attachment.  # noqa: E501

        :return: The field_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this GetCandidatesResponseDataAttachments.

        Field identifier for the attachment.  # noqa: E501

        :param field_id: The field_id of this GetCandidatesResponseDataAttachments.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataAttachments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataAttachments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesRequestFilters(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter_name': 'str',
        'possible_values': 'list[str]',
        'associativity': 'str'
    }

    attribute_map = {
        'filter_name': 'filterName',
        'possible_values': 'possibleValues',
        'associativity': 'associativity'
    }

    def __init__(self, filter_name=None, possible_values=None, associativity=None):  # noqa: E501
        """GetCandidatesRequestFilters - a model defined in Swagger"""  # noqa: E501
        self._filter_name = None
        self._possible_values = None
        self._associativity = None
        self.discriminator = None
        if filter_name is not None:
            self.filter_name = filter_name
        if possible_values is not None:
            self.possible_values = possible_values
        if associativity is not None:
            self.associativity = associativity

    @property
    def filter_name(self):
        """Gets the filter_name of this GetCandidatesRequestFilters.  # noqa: E501

        Dpecific filter types that can be applied.  # noqa: E501

        :return: The filter_name of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: str
        """
        return self._filter_name

    @filter_name.setter
    def filter_name(self, filter_name):
        """Sets the filter_name of this GetCandidatesRequestFilters.

        Dpecific filter types that can be applied.  # noqa: E501

        :param filter_name: The filter_name of this GetCandidatesRequestFilters.  # noqa: E501
        :type: str
        """

        self._filter_name = filter_name

    @property
    def possible_values(self):
        """Gets the possible_values of this GetCandidatesRequestFilters.  # noqa: E501

        Possible values within a list of values corresponding to the filter selected.  # noqa: E501

        :return: The possible_values of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: list[str]
        """
        return self._possible_values

    @possible_values.setter
    def possible_values(self, possible_values):
        """Sets the possible_values of this GetCandidatesRequestFilters.

        Possible values within a list of values corresponding to the filter selected.  # noqa: E501

        :param possible_values: The possible_values of this GetCandidatesRequestFilters.  # noqa: E501
        :type: list[str]
        """

        self._possible_values = possible_values

    @property
    def associativity(self):
        """Gets the associativity of this GetCandidatesRequestFilters.  # noqa: E501

        Condition to apply either and || or.  # noqa: E501

        :return: The associativity of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: str
        """
        return self._associativity

    @associativity.setter
    def associativity(self, associativity):
        """Sets the associativity of this GetCandidatesRequestFilters.

        Condition to apply either and || or.  # noqa: E501

        :param associativity: The associativity of this GetCandidatesRequestFilters.  # noqa: E501
        :type: str
        """

        self._associativity = associativity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesRequestFilters, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesRequestFilters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class NextHiringStatusData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hiring_status_list': 'list[NextHiringStatusDataHiringStatusList]'
    }

    attribute_map = {
        'hiring_status_list': 'hiringStatusList'
    }

    def __init__(self, hiring_status_list=None):  # noqa: E501
        """NextHiringStatusData - a model defined in Swagger"""  # noqa: E501
        self._hiring_status_list = None
        self.discriminator = None
        if hiring_status_list is not None:
            self.hiring_status_list = hiring_status_list

    @property
    def hiring_status_list(self):
        """Gets the hiring_status_list of this NextHiringStatusData.  # noqa: E501

        List of hiring statuses and their properties.  # noqa: E501

        :return: The hiring_status_list of this NextHiringStatusData.  # noqa: E501
        :rtype: list[NextHiringStatusDataHiringStatusList]
        """
        return self._hiring_status_list

    @hiring_status_list.setter
    def hiring_status_list(self, hiring_status_list):
        """Sets the hiring_status_list of this NextHiringStatusData.

        List of hiring statuses and their properties.  # noqa: E501

        :param hiring_status_list: The hiring_status_list of this NextHiringStatusData.  # noqa: E501
        :type: list[NextHiringStatusDataHiringStatusList]
        """

        self._hiring_status_list = hiring_status_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NextHiringStatusData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NextHiringStatusData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Posting(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locale': 'str',
        'site_type': 'str',
        'category': 'str',
        'title': 'str',
        'description': 'str',
        'apply_url': 'str',
        'visibility_locale': 'list[str]',
        'visibility_site_type': 'list[str]'
    }

    attribute_map = {
        'locale': 'locale',
        'site_type': 'siteType',
        'category': 'category',
        'title': 'title',
        'description': 'description',
        'apply_url': 'applyUrl',
        'visibility_locale': 'visibilityLocale',
        'visibility_site_type': 'visibilitySiteType'
    }

    def __init__(self, locale=None, site_type=None, category=None, title=None, description=None, apply_url=None, visibility_locale=None, visibility_site_type=None):  # noqa: E501
        """Posting - a model defined in Swagger"""  # noqa: E501
        self._locale = None
        self._site_type = None
        self._category = None
        self._title = None
        self._description = None
        self._apply_url = None
        self._visibility_locale = None
        self._visibility_site_type = None
        self.discriminator = None
        self.locale = locale
        self.site_type = site_type
        if category is not None:
            self.category = category
        if title is not None:
            self.title = title
        if description is not None:
            self.description = description
        if apply_url is not None:
            self.apply_url = apply_url
        if visibility_locale is not None:
            self.visibility_locale = visibility_locale
        if visibility_site_type is not None:
            self.visibility_site_type = visibility_site_type

    @property
    def locale(self):
        """Gets the locale of this Posting.  # noqa: E501

        Locale of the site (Language_Country).  # noqa: E501

        :return: The locale of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this Posting.

        Locale of the site (Language_Country).  # noqa: E501

        :param locale: The locale of this Posting.  # noqa: E501
        :type: str
        """
        if locale is None:
            raise ValueError("Invalid value for `locale`, must not be `None`")  # noqa: E501

        self._locale = locale

    @property
    def site_type(self):
        """Gets the site_type of this Posting.  # noqa: E501

        SiteType of the job.  # noqa: E501

        :return: The site_type of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this Posting.

        SiteType of the job.  # noqa: E501

        :param site_type: The site_type of this Posting.  # noqa: E501
        :type: str
        """
        if site_type is None:
            raise ValueError("Invalid value for `site_type`, must not be `None`")  # noqa: E501

        self._site_type = site_type

    @property
    def category(self):
        """Gets the category of this Posting.  # noqa: E501

        Category of the job.  # noqa: E501

        :return: The category of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Posting.

        Category of the job.  # noqa: E501

        :param category: The category of this Posting.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def title(self):
        """Gets the title of this Posting.  # noqa: E501

        ATS job title.  # noqa: E501

        :return: The title of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Posting.

        ATS job title.  # noqa: E501

        :param title: The title of this Posting.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def description(self):
        """Gets the description of this Posting.  # noqa: E501

        Description of the job.  # noqa: E501

        :return: The description of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Posting.

        Description of the job.  # noqa: E501

        :param description: The description of this Posting.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def apply_url(self):
        """Gets the apply_url of this Posting.  # noqa: E501

        Apply url of the job.  # noqa: E501

        :return: The apply_url of this Posting.  # noqa: E501
        :rtype: str
        """
        return self._apply_url

    @apply_url.setter
    def apply_url(self, apply_url):
        """Sets the apply_url of this Posting.

        Apply url of the job.  # noqa: E501

        :param apply_url: The apply_url of this Posting.  # noqa: E501
        :type: str
        """

        self._apply_url = apply_url

    @property
    def visibility_locale(self):
        """Gets the visibility_locale of this Posting.  # noqa: E501

        All locales that the job belongs to.  # noqa: E501

        :return: The visibility_locale of this Posting.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_locale

    @visibility_locale.setter
    def visibility_locale(self, visibility_locale):
        """Sets the visibility_locale of this Posting.

        All locales that the job belongs to.  # noqa: E501

        :param visibility_locale: The visibility_locale of this Posting.  # noqa: E501
        :type: list[str]
        """

        self._visibility_locale = visibility_locale

    @property
    def visibility_site_type(self):
        """Gets the visibility_site_type of this Posting.  # noqa: E501

        All personas that the jobs belongs to.  # noqa: E501

        :return: The visibility_site_type of this Posting.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility_site_type

    @visibility_site_type.setter
    def visibility_site_type(self, visibility_site_type):
        """Sets the visibility_site_type of this Posting.

        All personas that the jobs belongs to.  # noqa: E501

        :param visibility_site_type: The visibility_site_type of this Posting.  # noqa: E501
        :type: list[str]
        """

        self._visibility_site_type = visibility_site_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Posting, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Posting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsMultiCategory(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_category_id': 'str',
        'category': 'str',
        'category_raw': 'str',
        'primary_locale_category': 'str'
    }

    attribute_map = {
        'internal_category_id': 'internalCategoryId',
        'category': 'category',
        'category_raw': 'category_raw',
        'primary_locale_category': 'primaryLocaleCategory'
    }

    def __init__(self, internal_category_id=None, category=None, category_raw=None, primary_locale_category=None):  # noqa: E501
        """JobDetailsMultiCategory - a model defined in Swagger"""  # noqa: E501
        self._internal_category_id = None
        self._category = None
        self._category_raw = None
        self._primary_locale_category = None
        self.discriminator = None
        if internal_category_id is not None:
            self.internal_category_id = internal_category_id
        if category is not None:
            self.category = category
        if category_raw is not None:
            self.category_raw = category_raw
        if primary_locale_category is not None:
            self.primary_locale_category = primary_locale_category

    @property
    def internal_category_id(self):
        """Gets the internal_category_id of this JobDetailsMultiCategory.  # noqa: E501

        Internal category identifier.  # noqa: E501

        :return: The internal_category_id of this JobDetailsMultiCategory.  # noqa: E501
        :rtype: str
        """
        return self._internal_category_id

    @internal_category_id.setter
    def internal_category_id(self, internal_category_id):
        """Sets the internal_category_id of this JobDetailsMultiCategory.

        Internal category identifier.  # noqa: E501

        :param internal_category_id: The internal_category_id of this JobDetailsMultiCategory.  # noqa: E501
        :type: str
        """

        self._internal_category_id = internal_category_id

    @property
    def category(self):
        """Gets the category of this JobDetailsMultiCategory.  # noqa: E501

        Category name.  # noqa: E501

        :return: The category of this JobDetailsMultiCategory.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this JobDetailsMultiCategory.

        Category name.  # noqa: E501

        :param category: The category of this JobDetailsMultiCategory.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def category_raw(self):
        """Gets the category_raw of this JobDetailsMultiCategory.  # noqa: E501

        Category raw name.  # noqa: E501

        :return: The category_raw of this JobDetailsMultiCategory.  # noqa: E501
        :rtype: str
        """
        return self._category_raw

    @category_raw.setter
    def category_raw(self, category_raw):
        """Sets the category_raw of this JobDetailsMultiCategory.

        Category raw name.  # noqa: E501

        :param category_raw: The category_raw of this JobDetailsMultiCategory.  # noqa: E501
        :type: str
        """

        self._category_raw = category_raw

    @property
    def primary_locale_category(self):
        """Gets the primary_locale_category of this JobDetailsMultiCategory.  # noqa: E501

        Primary locale category.  # noqa: E501

        :return: The primary_locale_category of this JobDetailsMultiCategory.  # noqa: E501
        :rtype: str
        """
        return self._primary_locale_category

    @primary_locale_category.setter
    def primary_locale_category(self, primary_locale_category):
        """Sets the primary_locale_category of this JobDetailsMultiCategory.

        Primary locale category.  # noqa: E501

        :param primary_locale_category: The primary_locale_category of this JobDetailsMultiCategory.  # noqa: E501
        :type: str
        """

        self._primary_locale_category = primary_locale_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsMultiCategory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsMultiCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataEmailList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'email': 'str',
        'field_id': 'str',
        'status': 'str'
    }

    attribute_map = {
        'type': 'type',
        'email': 'email',
        'field_id': 'fieldID',
        'status': 'status'
    }

    def __init__(self, type=None, email=None, field_id=None, status=None):  # noqa: E501
        """GetCandidatesResponseDataEmailList - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._email = None
        self._field_id = None
        self._status = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if email is not None:
            self.email = email
        if field_id is not None:
            self.field_id = field_id
        if status is not None:
            self.status = status

    @property
    def type(self):
        """Gets the type of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Indicates whether the email is primary or secondary.  # noqa: E501

        :return: The type of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetCandidatesResponseDataEmailList.

        Indicates whether the email is primary or secondary.  # noqa: E501

        :param type: The type of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def email(self):
        """Gets the email of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Email address of the candidate.  # noqa: E501

        :return: The email of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetCandidatesResponseDataEmailList.

        Email address of the candidate.  # noqa: E501

        :param email: The email of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def field_id(self):
        """Gets the field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Field identifier for the email.  # noqa: E501

        :return: The field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this GetCandidatesResponseDataEmailList.

        Field identifier for the email.  # noqa: E501

        :param field_id: The field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def status(self):
        """Gets the status of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Status of the email.  # noqa: E501

        :return: The status of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetCandidatesResponseDataEmailList.

        Status of the email.  # noqa: E501

        :param status: The status of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataEmailList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataEmailList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsVariations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company': 'str',
        'posting_status': 'str',
        'language_code': 'str',
        'locale': 'str',
        'job_category': 'str',
        'job_title': 'str',
        'branding': 'str',
        'country_code': 'str',
        'site_type': 'list[str]'
    }

    attribute_map = {
        'company': 'company',
        'posting_status': 'postingStatus',
        'language_code': 'languageCode',
        'locale': 'locale',
        'job_category': 'jobCategory',
        'job_title': 'jobTitle',
        'branding': 'branding',
        'country_code': 'countryCode',
        'site_type': 'siteType'
    }

    def __init__(self, company=None, posting_status=None, language_code=None, locale=None, job_category=None, job_title=None, branding=None, country_code=None, site_type=None):  # noqa: E501
        """JobDetailsVariations - a model defined in Swagger"""  # noqa: E501
        self._company = None
        self._posting_status = None
        self._language_code = None
        self._locale = None
        self._job_category = None
        self._job_title = None
        self._branding = None
        self._country_code = None
        self._site_type = None
        self.discriminator = None
        if company is not None:
            self.company = company
        if posting_status is not None:
            self.posting_status = posting_status
        if language_code is not None:
            self.language_code = language_code
        if locale is not None:
            self.locale = locale
        if job_category is not None:
            self.job_category = job_category
        if job_title is not None:
            self.job_title = job_title
        if branding is not None:
            self.branding = branding
        if country_code is not None:
            self.country_code = country_code
        if site_type is not None:
            self.site_type = site_type

    @property
    def company(self):
        """Gets the company of this JobDetailsVariations.  # noqa: E501

        The company name.  # noqa: E501

        :return: The company of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this JobDetailsVariations.

        The company name.  # noqa: E501

        :param company: The company of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._company = company

    @property
    def posting_status(self):
        """Gets the posting_status of this JobDetailsVariations.  # noqa: E501

        The posting status.  # noqa: E501

        :return: The posting_status of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._posting_status

    @posting_status.setter
    def posting_status(self, posting_status):
        """Sets the posting_status of this JobDetailsVariations.

        The posting status.  # noqa: E501

        :param posting_status: The posting_status of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._posting_status = posting_status

    @property
    def language_code(self):
        """Gets the language_code of this JobDetailsVariations.  # noqa: E501

        The language code.  # noqa: E501

        :return: The language_code of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """Sets the language_code of this JobDetailsVariations.

        The language code.  # noqa: E501

        :param language_code: The language_code of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._language_code = language_code

    @property
    def locale(self):
        """Gets the locale of this JobDetailsVariations.  # noqa: E501

        The locale.  # noqa: E501

        :return: The locale of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobDetailsVariations.

        The locale.  # noqa: E501

        :param locale: The locale of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def job_category(self):
        """Gets the job_category of this JobDetailsVariations.  # noqa: E501

        The job's category.  # noqa: E501

        :return: The job_category of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this JobDetailsVariations.

        The job's category.  # noqa: E501

        :param job_category: The job_category of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._job_category = job_category

    @property
    def job_title(self):
        """Gets the job_title of this JobDetailsVariations.  # noqa: E501

        The job's title.  # noqa: E501

        :return: The job_title of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this JobDetailsVariations.

        The job's title.  # noqa: E501

        :param job_title: The job_title of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def branding(self):
        """Gets the branding of this JobDetailsVariations.  # noqa: E501

        The branding.  # noqa: E501

        :return: The branding of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._branding

    @branding.setter
    def branding(self, branding):
        """Sets the branding of this JobDetailsVariations.

        The branding.  # noqa: E501

        :param branding: The branding of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._branding = branding

    @property
    def country_code(self):
        """Gets the country_code of this JobDetailsVariations.  # noqa: E501

        The country code.  # noqa: E501

        :return: The country_code of this JobDetailsVariations.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this JobDetailsVariations.

        The country code.  # noqa: E501

        :param country_code: The country_code of this JobDetailsVariations.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def site_type(self):
        """Gets the site_type of this JobDetailsVariations.  # noqa: E501

        The site type  # noqa: E501

        :return: The site_type of this JobDetailsVariations.  # noqa: E501
        :rtype: list[str]
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobDetailsVariations.

        The site type  # noqa: E501

        :param site_type: The site_type of this JobDetailsVariations.  # noqa: E501
        :type: list[str]
        """

        self._site_type = site_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsVariations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsVariations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobNode(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'job_id': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str'
    }

    attribute_map = {
        'title': 'title',
        'job_id': 'jobId',
        'city': 'city',
        'state': 'state',
        'country': 'country'
    }

    def __init__(self, title=None, job_id=None, city=None, state=None, country=None):  # noqa: E501
        """JobNode - a model defined in Swagger"""  # noqa: E501
        self._title = None
        self._job_id = None
        self._city = None
        self._state = None
        self._country = None
        self.discriminator = None
        if title is not None:
            self.title = title
        if job_id is not None:
            self.job_id = job_id
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country

    @property
    def title(self):
        """Gets the title of this JobNode.  # noqa: E501

        Title of the recommended job.  # noqa: E501

        :return: The title of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this JobNode.

        Title of the recommended job.  # noqa: E501

        :param title: The title of this JobNode.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def job_id(self):
        """Gets the job_id of this JobNode.  # noqa: E501

        Unique identifier for a job.  # noqa: E501

        :return: The job_id of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobNode.

        Unique identifier for a job.  # noqa: E501

        :param job_id: The job_id of this JobNode.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def city(self):
        """Gets the city of this JobNode.  # noqa: E501

        Primary city of the job's location.  # noqa: E501

        :return: The city of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this JobNode.

        Primary city of the job's location.  # noqa: E501

        :param city: The city of this JobNode.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this JobNode.  # noqa: E501

        Primary state of the job's location.  # noqa: E501

        :return: The state of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobNode.

        Primary state of the job's location.  # noqa: E501

        :param state: The state of this JobNode.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this JobNode.  # noqa: E501

        Primary country of the job's location.  # noqa: E501

        :return: The country of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this JobNode.

        Primary country of the job's location.  # noqa: E501

        :param country: The country of this JobNode.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ApplicantsPagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total': 'float',
        'size': 'float',
        '_from': 'float'
    }

    attribute_map = {
        'total': 'total',
        'size': 'size',
        '_from': 'from'
    }

    def __init__(self, total=None, size=None, _from=None):  # noqa: E501
        """ApplicantsPagination - a model defined in Swagger"""  # noqa: E501
        self._total = None
        self._size = None
        self.__from = None
        self.discriminator = None
        if total is not None:
            self.total = total
        if size is not None:
            self.size = size
        if _from is not None:
            self._from = _from

    @property
    def total(self):
        """Gets the total of this ApplicantsPagination.  # noqa: E501

        Total number of candidates in the dataset.  # noqa: E501

        :return: The total of this ApplicantsPagination.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ApplicantsPagination.

        Total number of candidates in the dataset.  # noqa: E501

        :param total: The total of this ApplicantsPagination.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def size(self):
        """Gets the size of this ApplicantsPagination.  # noqa: E501

        Number of candidates returned in the current response.  # noqa: E501

        :return: The size of this ApplicantsPagination.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ApplicantsPagination.

        Number of candidates returned in the current response.  # noqa: E501

        :param size: The size of this ApplicantsPagination.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this ApplicantsPagination.  # noqa: E501

        Index of the first candidate in the current result set.  # noqa: E501

        :return: The _from of this ApplicantsPagination.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this ApplicantsPagination.

        Index of the first candidate in the current result set.  # noqa: E501

        :param _from: The _from of this ApplicantsPagination.  # noqa: E501
        :type: float
        """

        self.__from = _from

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicantsPagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicantsPagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from phenom.api.campaignssms.sms_campaigns_api import SMSCampaignsApi
from phenom.api.campaignsemail.email_campaigns_api import EmailCampaignsApi

class Campaigns:
    def __init__(self, token, gateway_url, apikey):
        self.__token = token
        self.__gateway_url = gateway_url
        self.__apikey = apikey

    def sms_campaigns_api(self):
        return SMSCampaignsApi(self.__token, self.__gateway_url, self.__apikey)

    def email_campaigns_api(self):
        return EmailCampaignsApi(self.__token, self.__gateway_url, self.__apikey)